challenge

package
v0.0.0-...-1b9e5be Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 8, 2024 License: BSD-3-Clause Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the challenge type in the database.
	Label = "challenge"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldMedia holds the string denoting the media field in the database.
	FieldMedia = "media"
	// FieldPrompt holds the string denoting the prompt field in the database.
	FieldPrompt = "prompt"
	// FieldResponse holds the string denoting the response field in the database.
	FieldResponse = "response"
	// FieldValue holds the string denoting the value field in the database.
	FieldValue = "value"
	// EdgeChallengeGroup holds the string denoting the challenge_group edge name in mutations.
	EdgeChallengeGroup = "challenge_group"
	// Table holds the table name of the challenge in the database.
	Table = "challenges"
	// ChallengeGroupTable is the table that holds the challenge_group relation/edge. The primary key declared below.
	ChallengeGroupTable = "challenge_group_challenges"
	// ChallengeGroupInverseTable is the table name for the ChallengeGroup entity.
	// It exists in this package in order to avoid circular dependency with the "challengegroup" package.
	ChallengeGroupInverseTable = "challenge_groups"
)

Variables

var (
	// ChallengeGroupPrimaryKey and ChallengeGroupColumn2 are the table columns denoting the
	// primary key for the challenge_group relation (M2M).
	ChallengeGroupPrimaryKey = []string{"challenge_group_id", "challenge_id"}
)

Columns holds all SQL columns for challenge fields.

Functions

func And

func And(predicates ...predicate.Challenge) predicate.Challenge

And groups predicates with the AND operator between them.

func HasChallengeGroup

func HasChallengeGroup() predicate.Challenge

HasChallengeGroup applies the HasEdge predicate on the "challenge_group" edge.

func HasChallengeGroupWith

func HasChallengeGroupWith(preds ...predicate.ChallengeGroup) predicate.Challenge

HasChallengeGroupWith applies the HasEdge predicate on the "challenge_group" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Challenge

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Challenge

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Challenge

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Challenge

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Challenge

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Challenge

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Challenge

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Challenge

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Challenge

IDNotIn applies the NotIn predicate on the ID field.

func Media

func Media(v string) predicate.Challenge

Media applies equality check predicate on the "media" field. It's identical to MediaEQ.

func MediaContains

func MediaContains(v string) predicate.Challenge

MediaContains applies the Contains predicate on the "media" field.

func MediaContainsFold

func MediaContainsFold(v string) predicate.Challenge

MediaContainsFold applies the ContainsFold predicate on the "media" field.

func MediaEQ

func MediaEQ(v string) predicate.Challenge

MediaEQ applies the EQ predicate on the "media" field.

func MediaEqualFold

func MediaEqualFold(v string) predicate.Challenge

MediaEqualFold applies the EqualFold predicate on the "media" field.

func MediaGT

func MediaGT(v string) predicate.Challenge

MediaGT applies the GT predicate on the "media" field.

func MediaGTE

func MediaGTE(v string) predicate.Challenge

MediaGTE applies the GTE predicate on the "media" field.

func MediaHasPrefix

func MediaHasPrefix(v string) predicate.Challenge

MediaHasPrefix applies the HasPrefix predicate on the "media" field.

func MediaHasSuffix

func MediaHasSuffix(v string) predicate.Challenge

MediaHasSuffix applies the HasSuffix predicate on the "media" field.

func MediaIn

func MediaIn(vs ...string) predicate.Challenge

MediaIn applies the In predicate on the "media" field.

func MediaLT

func MediaLT(v string) predicate.Challenge

MediaLT applies the LT predicate on the "media" field.

func MediaLTE

func MediaLTE(v string) predicate.Challenge

MediaLTE applies the LTE predicate on the "media" field.

func MediaNEQ

func MediaNEQ(v string) predicate.Challenge

MediaNEQ applies the NEQ predicate on the "media" field.

func MediaNotIn

func MediaNotIn(vs ...string) predicate.Challenge

MediaNotIn applies the NotIn predicate on the "media" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Challenge) predicate.Challenge

Or groups predicates with the OR operator between them.

func Prompt

func Prompt(v string) predicate.Challenge

Prompt applies equality check predicate on the "prompt" field. It's identical to PromptEQ.

func PromptContains

func PromptContains(v string) predicate.Challenge

PromptContains applies the Contains predicate on the "prompt" field.

func PromptContainsFold

func PromptContainsFold(v string) predicate.Challenge

PromptContainsFold applies the ContainsFold predicate on the "prompt" field.

func PromptEQ

func PromptEQ(v string) predicate.Challenge

PromptEQ applies the EQ predicate on the "prompt" field.

func PromptEqualFold

func PromptEqualFold(v string) predicate.Challenge

PromptEqualFold applies the EqualFold predicate on the "prompt" field.

func PromptGT

func PromptGT(v string) predicate.Challenge

PromptGT applies the GT predicate on the "prompt" field.

func PromptGTE

func PromptGTE(v string) predicate.Challenge

PromptGTE applies the GTE predicate on the "prompt" field.

func PromptHasPrefix

func PromptHasPrefix(v string) predicate.Challenge

PromptHasPrefix applies the HasPrefix predicate on the "prompt" field.

func PromptHasSuffix

func PromptHasSuffix(v string) predicate.Challenge

PromptHasSuffix applies the HasSuffix predicate on the "prompt" field.

func PromptIn

func PromptIn(vs ...string) predicate.Challenge

PromptIn applies the In predicate on the "prompt" field.

func PromptLT

func PromptLT(v string) predicate.Challenge

PromptLT applies the LT predicate on the "prompt" field.

func PromptLTE

func PromptLTE(v string) predicate.Challenge

PromptLTE applies the LTE predicate on the "prompt" field.

func PromptNEQ

func PromptNEQ(v string) predicate.Challenge

PromptNEQ applies the NEQ predicate on the "prompt" field.

func PromptNotIn

func PromptNotIn(vs ...string) predicate.Challenge

PromptNotIn applies the NotIn predicate on the "prompt" field.

func Response

func Response(v string) predicate.Challenge

Response applies equality check predicate on the "response" field. It's identical to ResponseEQ.

func ResponseContains

func ResponseContains(v string) predicate.Challenge

ResponseContains applies the Contains predicate on the "response" field.

func ResponseContainsFold

func ResponseContainsFold(v string) predicate.Challenge

ResponseContainsFold applies the ContainsFold predicate on the "response" field.

func ResponseEQ

func ResponseEQ(v string) predicate.Challenge

ResponseEQ applies the EQ predicate on the "response" field.

func ResponseEqualFold

func ResponseEqualFold(v string) predicate.Challenge

ResponseEqualFold applies the EqualFold predicate on the "response" field.

func ResponseGT

func ResponseGT(v string) predicate.Challenge

ResponseGT applies the GT predicate on the "response" field.

func ResponseGTE

func ResponseGTE(v string) predicate.Challenge

ResponseGTE applies the GTE predicate on the "response" field.

func ResponseHasPrefix

func ResponseHasPrefix(v string) predicate.Challenge

ResponseHasPrefix applies the HasPrefix predicate on the "response" field.

func ResponseHasSuffix

func ResponseHasSuffix(v string) predicate.Challenge

ResponseHasSuffix applies the HasSuffix predicate on the "response" field.

func ResponseIn

func ResponseIn(vs ...string) predicate.Challenge

ResponseIn applies the In predicate on the "response" field.

func ResponseLT

func ResponseLT(v string) predicate.Challenge

ResponseLT applies the LT predicate on the "response" field.

func ResponseLTE

func ResponseLTE(v string) predicate.Challenge

ResponseLTE applies the LTE predicate on the "response" field.

func ResponseNEQ

func ResponseNEQ(v string) predicate.Challenge

ResponseNEQ applies the NEQ predicate on the "response" field.

func ResponseNotIn

func ResponseNotIn(vs ...string) predicate.Challenge

ResponseNotIn applies the NotIn predicate on the "response" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Value

func Value(v int) predicate.Challenge

Value applies equality check predicate on the "value" field. It's identical to ValueEQ.

func ValueEQ

func ValueEQ(v int) predicate.Challenge

ValueEQ applies the EQ predicate on the "value" field.

func ValueGT

func ValueGT(v int) predicate.Challenge

ValueGT applies the GT predicate on the "value" field.

func ValueGTE

func ValueGTE(v int) predicate.Challenge

ValueGTE applies the GTE predicate on the "value" field.

func ValueIn

func ValueIn(vs ...int) predicate.Challenge

ValueIn applies the In predicate on the "value" field.

func ValueLT

func ValueLT(v int) predicate.Challenge

ValueLT applies the LT predicate on the "value" field.

func ValueLTE

func ValueLTE(v int) predicate.Challenge

ValueLTE applies the LTE predicate on the "value" field.

func ValueNEQ

func ValueNEQ(v int) predicate.Challenge

ValueNEQ applies the NEQ predicate on the "value" field.

func ValueNotIn

func ValueNotIn(vs ...int) predicate.Challenge

ValueNotIn applies the NotIn predicate on the "value" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Challenge queries.

func ByChallengeGroup

func ByChallengeGroup(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByChallengeGroup orders the results by challenge_group terms.

func ByChallengeGroupCount

func ByChallengeGroupCount(opts ...sql.OrderTermOption) OrderOption

ByChallengeGroupCount orders the results by challenge_group count.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByMedia

func ByMedia(opts ...sql.OrderTermOption) OrderOption

ByMedia orders the results by the media field.

func ByPrompt

func ByPrompt(opts ...sql.OrderTermOption) OrderOption

ByPrompt orders the results by the prompt field.

func ByResponse

func ByResponse(opts ...sql.OrderTermOption) OrderOption

ByResponse orders the results by the response field.

func ByValue

func ByValue(opts ...sql.OrderTermOption) OrderOption

ByValue orders the results by the value field.

Jump to