episoderound

package
v0.0.0-...-1b9e5be Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 8, 2024 License: BSD-3-Clause Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the episoderound type in the database.
	Label = "episode_round"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldRound holds the string denoting the round field in the database.
	FieldRound = "round"
	// EdgeCategories holds the string denoting the categories edge name in mutations.
	EdgeCategories = "categories"
	// EdgeEpisode holds the string denoting the episode edge name in mutations.
	EdgeEpisode = "episode"
	// Table holds the table name of the episoderound in the database.
	Table = "episode_rounds"
	// CategoriesTable is the table that holds the categories relation/edge. The primary key declared below.
	CategoriesTable = "episode_round_categories"
	// CategoriesInverseTable is the table name for the ChallengeGroup entity.
	// It exists in this package in order to avoid circular dependency with the "challengegroup" package.
	CategoriesInverseTable = "challenge_groups"
	// EpisodeTable is the table that holds the episode relation/edge. The primary key declared below.
	EpisodeTable = "episode_rounds"
	// EpisodeInverseTable is the table name for the Episode entity.
	// It exists in this package in order to avoid circular dependency with the "episode" package.
	EpisodeInverseTable = "episodes"
)

Variables

var (
	// CategoriesPrimaryKey and CategoriesColumn2 are the table columns denoting the
	// primary key for the categories relation (M2M).
	CategoriesPrimaryKey = []string{"episode_round_id", "challenge_group_id"}
	// EpisodePrimaryKey and EpisodeColumn2 are the table columns denoting the
	// primary key for the episode relation (M2M).
	EpisodePrimaryKey = []string{"episode_id", "episode_round_id"}
)
var Columns = []string{
	FieldID,
	FieldRound,
}

Columns holds all SQL columns for episoderound fields.

Functions

func And

func And(predicates ...predicate.EpisodeRound) predicate.EpisodeRound

And groups predicates with the AND operator between them.

func HasCategories

func HasCategories() predicate.EpisodeRound

HasCategories applies the HasEdge predicate on the "categories" edge.

func HasCategoriesWith

func HasCategoriesWith(preds ...predicate.ChallengeGroup) predicate.EpisodeRound

HasCategoriesWith applies the HasEdge predicate on the "categories" edge with a given conditions (other predicates).

func HasEpisode

func HasEpisode() predicate.EpisodeRound

HasEpisode applies the HasEdge predicate on the "episode" edge.

func HasEpisodeWith

func HasEpisodeWith(preds ...predicate.Episode) predicate.EpisodeRound

HasEpisodeWith applies the HasEdge predicate on the "episode" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.EpisodeRound

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.EpisodeRound

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.EpisodeRound

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.EpisodeRound

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.EpisodeRound

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.EpisodeRound

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.EpisodeRound

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.EpisodeRound

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.EpisodeRound

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.EpisodeRound) predicate.EpisodeRound

Or groups predicates with the OR operator between them.

func RoundEQ

func RoundEQ(v Round) predicate.EpisodeRound

RoundEQ applies the EQ predicate on the "round" field.

func RoundIn

func RoundIn(vs ...Round) predicate.EpisodeRound

RoundIn applies the In predicate on the "round" field.

func RoundNEQ

func RoundNEQ(v Round) predicate.EpisodeRound

RoundNEQ applies the NEQ predicate on the "round" field.

func RoundNotIn

func RoundNotIn(vs ...Round) predicate.EpisodeRound

RoundNotIn applies the NotIn predicate on the "round" field.

func RoundValidator

func RoundValidator(r Round) error

RoundValidator is a validator for the "round" field enum values. It is called by the builders before save.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the EpisodeRound queries.

func ByCategories

func ByCategories(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByCategories orders the results by categories terms.

func ByCategoriesCount

func ByCategoriesCount(opts ...sql.OrderTermOption) OrderOption

ByCategoriesCount orders the results by categories count.

func ByEpisode

func ByEpisode(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByEpisode orders the results by episode terms.

func ByEpisodeCount

func ByEpisodeCount(opts ...sql.OrderTermOption) OrderOption

ByEpisodeCount orders the results by episode count.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByRound

func ByRound(opts ...sql.OrderTermOption) OrderOption

ByRound orders the results by the round field.

type Round

type Round string

Round defines the type for the "round" enum field.

const (
	RoundUNKNOWN    Round = "UNKNOWN"
	RoundSingle     Round = "Single"
	RoundDouble     Round = "Double"
	RoundFinal      Round = "Final"
	RoundTiebreaker Round = "Tiebreaker"
)

Round values.

func (Round) String

func (r Round) String() string

Jump to