Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Challenge) predicate.Challenge
- func HasChallengeGroup() predicate.Challenge
- func HasChallengeGroupWith(preds ...predicate.ChallengeGroup) predicate.Challenge
- func ID(id int) predicate.Challenge
- func IDEQ(id int) predicate.Challenge
- func IDGT(id int) predicate.Challenge
- func IDGTE(id int) predicate.Challenge
- func IDIn(ids ...int) predicate.Challenge
- func IDLT(id int) predicate.Challenge
- func IDLTE(id int) predicate.Challenge
- func IDNEQ(id int) predicate.Challenge
- func IDNotIn(ids ...int) predicate.Challenge
- func Media(v string) predicate.Challenge
- func MediaContains(v string) predicate.Challenge
- func MediaContainsFold(v string) predicate.Challenge
- func MediaEQ(v string) predicate.Challenge
- func MediaEqualFold(v string) predicate.Challenge
- func MediaGT(v string) predicate.Challenge
- func MediaGTE(v string) predicate.Challenge
- func MediaHasPrefix(v string) predicate.Challenge
- func MediaHasSuffix(v string) predicate.Challenge
- func MediaIn(vs ...string) predicate.Challenge
- func MediaLT(v string) predicate.Challenge
- func MediaLTE(v string) predicate.Challenge
- func MediaNEQ(v string) predicate.Challenge
- func MediaNotIn(vs ...string) predicate.Challenge
- func Not(p predicate.Challenge) predicate.Challenge
- func Or(predicates ...predicate.Challenge) predicate.Challenge
- func Prompt(v string) predicate.Challenge
- func PromptContains(v string) predicate.Challenge
- func PromptContainsFold(v string) predicate.Challenge
- func PromptEQ(v string) predicate.Challenge
- func PromptEqualFold(v string) predicate.Challenge
- func PromptGT(v string) predicate.Challenge
- func PromptGTE(v string) predicate.Challenge
- func PromptHasPrefix(v string) predicate.Challenge
- func PromptHasSuffix(v string) predicate.Challenge
- func PromptIn(vs ...string) predicate.Challenge
- func PromptLT(v string) predicate.Challenge
- func PromptLTE(v string) predicate.Challenge
- func PromptNEQ(v string) predicate.Challenge
- func PromptNotIn(vs ...string) predicate.Challenge
- func Response(v string) predicate.Challenge
- func ResponseContains(v string) predicate.Challenge
- func ResponseContainsFold(v string) predicate.Challenge
- func ResponseEQ(v string) predicate.Challenge
- func ResponseEqualFold(v string) predicate.Challenge
- func ResponseGT(v string) predicate.Challenge
- func ResponseGTE(v string) predicate.Challenge
- func ResponseHasPrefix(v string) predicate.Challenge
- func ResponseHasSuffix(v string) predicate.Challenge
- func ResponseIn(vs ...string) predicate.Challenge
- func ResponseLT(v string) predicate.Challenge
- func ResponseLTE(v string) predicate.Challenge
- func ResponseNEQ(v string) predicate.Challenge
- func ResponseNotIn(vs ...string) predicate.Challenge
- func ValidColumn(column string) bool
- func Value(v int) predicate.Challenge
- func ValueEQ(v int) predicate.Challenge
- func ValueGT(v int) predicate.Challenge
- func ValueGTE(v int) predicate.Challenge
- func ValueIn(vs ...int) predicate.Challenge
- func ValueLT(v int) predicate.Challenge
- func ValueLTE(v int) predicate.Challenge
- func ValueNEQ(v int) predicate.Challenge
- func ValueNotIn(vs ...int) predicate.Challenge
- type OrderOption
- func ByChallengeGroup(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByChallengeGroupCount(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByMedia(opts ...sql.OrderTermOption) OrderOption
- func ByPrompt(opts ...sql.OrderTermOption) OrderOption
- func ByResponse(opts ...sql.OrderTermOption) OrderOption
- func ByValue(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the challenge type in the database. Label = "challenge" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldMedia holds the string denoting the media field in the database. FieldMedia = "media" // FieldPrompt holds the string denoting the prompt field in the database. FieldPrompt = "prompt" // FieldResponse holds the string denoting the response field in the database. FieldResponse = "response" // FieldValue holds the string denoting the value field in the database. FieldValue = "value" // EdgeChallengeGroup holds the string denoting the challenge_group edge name in mutations. EdgeChallengeGroup = "challenge_group" // Table holds the table name of the challenge in the database. Table = "challenges" // ChallengeGroupTable is the table that holds the challenge_group relation/edge. The primary key declared below. ChallengeGroupTable = "challenge_group_challenges" // ChallengeGroupInverseTable is the table name for the ChallengeGroup entity. // It exists in this package in order to avoid circular dependency with the "challengegroup" package. ChallengeGroupInverseTable = "challenge_groups" )
Variables ¶
var ( // ChallengeGroupPrimaryKey and ChallengeGroupColumn2 are the table columns denoting the // primary key for the challenge_group relation (M2M). ChallengeGroupPrimaryKey = []string{"challenge_group_id", "challenge_id"} )
var Columns = []string{ FieldID, FieldMedia, FieldPrompt, FieldResponse, FieldValue, }
Columns holds all SQL columns for challenge fields.
Functions ¶
func HasChallengeGroup ¶
HasChallengeGroup applies the HasEdge predicate on the "challenge_group" edge.
func HasChallengeGroupWith ¶
func HasChallengeGroupWith(preds ...predicate.ChallengeGroup) predicate.Challenge
HasChallengeGroupWith applies the HasEdge predicate on the "challenge_group" edge with a given conditions (other predicates).
func Media ¶
Media applies equality check predicate on the "media" field. It's identical to MediaEQ.
func MediaContains ¶
MediaContains applies the Contains predicate on the "media" field.
func MediaContainsFold ¶
MediaContainsFold applies the ContainsFold predicate on the "media" field.
func MediaEqualFold ¶
MediaEqualFold applies the EqualFold predicate on the "media" field.
func MediaHasPrefix ¶
MediaHasPrefix applies the HasPrefix predicate on the "media" field.
func MediaHasSuffix ¶
MediaHasSuffix applies the HasSuffix predicate on the "media" field.
func MediaNotIn ¶
MediaNotIn applies the NotIn predicate on the "media" field.
func Prompt ¶
Prompt applies equality check predicate on the "prompt" field. It's identical to PromptEQ.
func PromptContains ¶
PromptContains applies the Contains predicate on the "prompt" field.
func PromptContainsFold ¶
PromptContainsFold applies the ContainsFold predicate on the "prompt" field.
func PromptEqualFold ¶
PromptEqualFold applies the EqualFold predicate on the "prompt" field.
func PromptHasPrefix ¶
PromptHasPrefix applies the HasPrefix predicate on the "prompt" field.
func PromptHasSuffix ¶
PromptHasSuffix applies the HasSuffix predicate on the "prompt" field.
func PromptNotIn ¶
PromptNotIn applies the NotIn predicate on the "prompt" field.
func Response ¶
Response applies equality check predicate on the "response" field. It's identical to ResponseEQ.
func ResponseContains ¶
ResponseContains applies the Contains predicate on the "response" field.
func ResponseContainsFold ¶
ResponseContainsFold applies the ContainsFold predicate on the "response" field.
func ResponseEQ ¶
ResponseEQ applies the EQ predicate on the "response" field.
func ResponseEqualFold ¶
ResponseEqualFold applies the EqualFold predicate on the "response" field.
func ResponseGT ¶
ResponseGT applies the GT predicate on the "response" field.
func ResponseGTE ¶
ResponseGTE applies the GTE predicate on the "response" field.
func ResponseHasPrefix ¶
ResponseHasPrefix applies the HasPrefix predicate on the "response" field.
func ResponseHasSuffix ¶
ResponseHasSuffix applies the HasSuffix predicate on the "response" field.
func ResponseIn ¶
ResponseIn applies the In predicate on the "response" field.
func ResponseLT ¶
ResponseLT applies the LT predicate on the "response" field.
func ResponseLTE ¶
ResponseLTE applies the LTE predicate on the "response" field.
func ResponseNEQ ¶
ResponseNEQ applies the NEQ predicate on the "response" field.
func ResponseNotIn ¶
ResponseNotIn applies the NotIn predicate on the "response" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Value ¶
Value applies equality check predicate on the "value" field. It's identical to ValueEQ.
func ValueNotIn ¶
ValueNotIn applies the NotIn predicate on the "value" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Challenge queries.
func ByChallengeGroup ¶
func ByChallengeGroup(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByChallengeGroup orders the results by challenge_group terms.
func ByChallengeGroupCount ¶
func ByChallengeGroupCount(opts ...sql.OrderTermOption) OrderOption
ByChallengeGroupCount orders the results by challenge_group count.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByMedia ¶
func ByMedia(opts ...sql.OrderTermOption) OrderOption
ByMedia orders the results by the media field.
func ByPrompt ¶
func ByPrompt(opts ...sql.OrderTermOption) OrderOption
ByPrompt orders the results by the prompt field.
func ByResponse ¶
func ByResponse(opts ...sql.OrderTermOption) OrderOption
ByResponse orders the results by the response field.
func ByValue ¶
func ByValue(opts ...sql.OrderTermOption) OrderOption
ByValue orders the results by the value field.